@@ -118,7 +118,9 @@ if ctx.mode == 'configure':
 
     ctx.setenv('BUG_TRACKER', "http://sourceforge.net/tracker/?group_id=124080")
 
-    trans = ctx.env['ENABLE_TRANSLATIONS'] and ctx.env['ENABLE_NLS']
+    trans = (ctx.env['ENABLE_NLS'] == False) or \
+            (ctx.env['ENABLE_TRANSLATIONS'] == False)
+    trans = not trans
     if trans != False:
         try:
             ctx.find_prog_env("xgettext")
@@ -194,7 +196,7 @@ if ctx.mode == 'configure':
     ctx.setenv("WITH_GNOME_DEFAULT_APPLICATIONS", gda)
 
     ctx.pkg_config('gtk+-3.0', 'GTK', '3.10')
-    ctx.pkg_config('vte-2.91', 'VTE')
+    ctx.pkg_config('vte-2.91', 'VTE', '0.40')
     #vte_version = ctx.prog_output("${PKG_CONFIG} --modversion vte-2.91")[0]
     #ctx.setenv('NEED_TRANSPARENCY_FIX', vte_version >= "0.34.8")
     ctx.setenv('NEED_TRANSPARENCY_FIX', True)
@@ -418,7 +420,12 @@ elif ctx.mode == 'build':
                 deps = podir,
                 xgettext_opts = '-L Glade',
                 dir = "${ABS_TOP_DIR}/po"))
-        ctx.add_rule(Rule(sources = [code_pot, glade_pot],
+        if ctx.env['HAVE_PO4A']:
+            sources = [code_pot, glade_pot]
+        else:
+            sources = code_pot
+        print("roxterm.pot sources", sources)
+        ctx.add_rule(Rule(sources = sources,
                 targets = '${ABS_TOP_DIR}/po/${PACKAGE}.pot',
                 rule = '${MSGCAT} -o ${TGT} ${SRC}',
                 diffpat = gettext_diffpat))
@@ -503,7 +510,7 @@ elif ctx.mode == 'build':
                     "${SED} -i 's/SOME DESCRIPTIVE TITLE/" \
                             "Translations for roxterm docs/' ${TGT}",
                     "${SED} -i 's/Copyright (C) YEAR/" + \
-                            "Copyright (C) 2010-2014/' " \
+                            "Copyright (C) 2010-2015/' " \
                             "${TGT}",
                     "${SED} -i 's/FIRST AUTHOR <EMAIL@ADDRESS>, YEAR/"
                             "Tony Houghton <h@realh.co.uk>, 2014/' ${TGT}"],
@@ -534,7 +541,6 @@ elif ctx.mode == 'build':
                         dir = "${PO4ADIR}",
                         use_shell = True))
 
-
     # Translations (itstool)
     if ctx.env['HAVE_ITSTOOL']:
         podir = "${POXML_DIR}"
