@@ -1,6 +1,6 @@
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1080,8 +1080,6 @@ static GtkWidget *make_tab_label(MultiTab *tab, GtkPositionType tab_pos)
     {
         multi_tab_add_close_button(tab);
     }
-    gtk_notebook_set_tab_label(GTK_NOTEBOOK(tab->parent->notebook),
-        tab->widget, tab->label_box);
     gtk_widget_show_all(tab->label_box);
 
     return tab->label_box;
