@@ -1,6 +1,6 @@
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include "defns.h"
 
 #include <stdarg.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include "capplet.h"
@@ -41,7 +42,7 @@ struct _ProfileGUI {
     char *profile_name;
     gboolean ignore_destroy;
     struct {
-        guint sel_by_word : 1;
+        guint word_chars : 1;
         guint color_term : 1;
         guint term : 1;
         guint browser : 1;
@@ -100,7 +101,7 @@ static void profilegui_update_from_entry(ProfileGUI * pg, const char *name)
 
 void profilegui_check_entries_for_changes(ProfileGUI * pg)
 {
-    PG_UPDATE_IF(sel_by_word)
+    PG_UPDATE_IF(word_chars)
     PG_UPDATE_IF(color_term)
     PG_UPDATE_IF(term)
     PG_UPDATE_IF(browser)
@@ -149,7 +150,7 @@ void on_editable_changed(GtkEditable * editable, ProfileGUI *pg)
     const char *n = gtk_buildable_get_name(GTK_BUILDABLE(editable));
 #define PG_IF_CHANGED(s) if (!strcmp(n, #s)) PG_MEMBER(pg->changed, s) = 1
 
-    PG_IF_CHANGED(sel_by_word);
+    PG_IF_CHANGED(word_chars);
     else PG_IF_CHANGED(color_term);
     else PG_IF_CHANGED(term);
     else PG_IF_CHANGED(browser);
@@ -163,6 +164,13 @@ void on_editable_changed(GtkEditable * editable, ProfileGUI *pg)
     else PG_IF_CHANGED(ssh_user);
     else PG_IF_CHANGED(ssh_options);
     else PG_IF_CHANGED(win_title);
+    else if (!strcmp(n, "ssh_port"))
+    {
+        GtkAdjustment *adj = gtk_spin_button_get_adjustment(
+                GTK_SPIN_BUTTON(editable));
+        gtk_adjustment_set_value(adj,
+                atoi(gtk_entry_get_text(GTK_ENTRY(editable))));
+    }
 }
 
 void on_ssh_entry_activate(GtkEntry * entry, ProfileGUI * pg)
@@ -420,7 +428,7 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     capplet_set_radio(&pg->capp, "cursor_shape", 0);
     capplet_set_boolean_toggle(&pg->capp, "hide_mouse", TRUE);
     capplet_set_boolean_toggle(&pg->capp, "autowrap", TRUE);
-    capplet_set_text_entry(&pg->capp, "sel_by_word", "-A-Za-z0-9,./?%&#_");
+    capplet_set_text_entry(&pg->capp, "word_chars", "-,./?%&#_");
     capplet_set_text_entry(&pg->capp, "color_term", NULL);
     capplet_set_text_entry(&pg->capp, "term", NULL);
     capplet_set_float_range(&pg->capp, "saturation", 1.0);
@@ -549,7 +557,7 @@ ProfileGUI *profilegui_open(const char *profile_name, GdkScreen *scrn)
     static const char *adj_names[] = {
             "width_adjustment", "height_adjustment",
             "exit_pause_adjustment", "scrollback_lines_adjustment",
-            "saturation_adjustment",
+            "saturation_adjustment", "ssh_port_adjustment",
             NULL };
     static const char *obj_names[] = {
             "Profile_Editor", "ssh_dialog",
